Skip to contents

log likelihood of the Frechet distribution and its derivatives (from stan)

Usage

llikFrechet(x, alpha, sigma, full = FALSE)

Arguments

x

Observation

alpha

distribution parameter

sigma

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter