Skip to contents

log likelihood of the Gumbel distribution and its derivatives (from stan)

Usage

llikGumbel(x, mu, beta, full = FALSE)

Arguments

x

Observation

mu

distribution parameter

beta

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter