Skip to contents

log likelihood of the Lnorm distribution and its derivatives (from stan)

Usage

llikLnorm(x, meanlog, sdlog, full = FALSE)

Arguments

x

Observation

meanlog

distribution parameter

sdlog

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter