Skip to contents

log likelihood of the Logis distribution and its derivatives (from stan)

Usage

llikLogis(x, location, scale, full = FALSE)

Arguments

x

Observation

location

distribution parameter

scale

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter