Skip to contents

log likelihood of the Pareto distribution and its derivatives (from stan)

Usage

llikPareto(x, yMin, alpha, full = FALSE)

Arguments

x

Observation

yMin

distribution parameter

alpha

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter