Skip to contents

log likelihood of the Rayleigh distribution and its derivatives (from stan)

Usage

llikRayleigh(x, sigma, full = FALSE)

Arguments

x

Observation

sigma

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter