llikFrechet: log likelihood of the Frechet distribution and its...

View source: R/llikNew.R

llikFrechetR Documentation

log likelihood of the Frechet distribution and its derivatives (from stan)

Description

log likelihood of the Frechet distribution and its derivatives (from stan)

Usage

llikFrechet(x, alpha, sigma, full = FALSE)

Arguments

x

Observation

alpha

distribution parameter

sigma

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter


rxode2ll documentation built on Sept. 15, 2026, 5:10 p.m.