| llikGumbel | R Documentation |
log likelihood of the Gumbel distribution and its derivatives (from stan)
llikGumbel(x, mu, beta, full = FALSE)
x |
Observation |
mu |
distribution parameter |
beta |
distribution parameter |
full |
return the input parameters alongside the result |
data frame with fx and the derivative of each parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.