| llikLnorm | R Documentation |
log likelihood of the Lnorm distribution and its derivatives (from stan)
llikLnorm(x, meanlog, sdlog, full = FALSE)
x |
Observation |
meanlog |
distribution parameter |
sdlog |
distribution parameter |
full |
return the input parameters alongside the result |
data frame with fx and the derivative of each parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.