llikLogis: log likelihood of the Logis distribution and its derivatives...

View source: R/llikNew.R

llikLogisR Documentation

log likelihood of the Logis distribution and its derivatives (from stan)

Description

log likelihood of the Logis distribution and its derivatives (from stan)

Usage

llikLogis(x, location, scale, full = FALSE)

Arguments

x

Observation

location

distribution parameter

scale

distribution parameter

full

return the input parameters alongside the result

Value

data frame with fx and the derivative of each parameter


rxode2ll documentation built on Sept. 15, 2026, 5:10 p.m.