| llikLogis | R Documentation |
log likelihood of the Logis distribution and its derivatives (from stan)
llikLogis(x, location, scale, full = FALSE)
x |
Observation |
location |
distribution parameter |
scale |
distribution parameter |
full |
return the input parameters alongside the result |
data frame with fx and the derivative of each parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.