| llikPareto | R Documentation |
log likelihood of the Pareto distribution and its derivatives (from stan)
llikPareto(x, yMin, alpha, full = FALSE)
x |
Observation |
yMin |
distribution parameter |
alpha |
distribution parameter |
full |
return the input parameters alongside the result |
data frame with fx and the derivative of each parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.