| llikRayleigh | R Documentation |
log likelihood of the Rayleigh distribution and its derivatives (from stan)
llikRayleigh(x, sigma, full = FALSE)
x |
Observation |
sigma |
distribution parameter |
full |
return the input parameters alongside the result |
data frame with fx and the derivative of each parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.